package cn.com.infosec.ocsp;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1OutputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.ocsp.OCSPRequest;
import cn.com.infosec.asn1.ocsp.Request;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.X509Extensions;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.InvalidAlgorithmParameterException;
import java.security.NoSuchProviderException;
import java.security.PublicKey;
import java.security.Signature;
import java.security.cert.CertStore;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.CollectionCertStoreParameters;
import java.security.cert.X509Certificate;
import java.security.cert.X509Extension;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class OCSPReq implements X509Extension {
   private OCSPRequest req;

   public OCSPReq(OCSPRequest req) {
      this.req = req;
   }

   public OCSPReq(byte[] req) {
      OCSPReq var10000 = this;
      ASN1InputStream var2;
      var2 = new ASN1InputStream.<init>(req);
      var10000.<init>(var2);
   }

   public OCSPReq(InputStream in) {
      OCSPReq var10000 = this;
      ASN1InputStream var2;
      var2 = new ASN1InputStream.<init>(in);
      var10000.<init>(var2);
   }

   private OCSPReq(ASN1InputStream aIn) {
      OCSPReq var10000 = this;
      ASN1InputStream var10001 = aIn;
      super();

      try {
         var10000.req = OCSPRequest.getInstance(var10001.readObject());
      } catch (IllegalArgumentException var2) {
         throw new IOException("malformed request: " + var2.getMessage());
      } catch (ClassCastException var3) {
         throw new IOException("malformed request: " + var3.getMessage());
      }
   }

   private List getCertList(String provider) {
      OCSPReq var10000 = this;
      ArrayList var8;
      var8 = new ArrayList.<init>();
      ByteArrayOutputStream var2;
      var2 = new ByteArrayOutputStream.<init>();
      ASN1OutputStream var3;
      var3 = new ASN1OutputStream.<init>(var2);

      CertificateFactory var10001;
      try {
         var10001 = CertificateFactory.getInstance("X.509", provider);
      } catch (CertificateException var7) {
         throw new OCSPException("can't get certificate factory.", var7);
      }

      CertificateFactory provider1 = var10001;
      ASN1Sequence var4;
      ByteArrayOutputStream var11;
      if ((var4 = var10000.req.getOptionalSignature().getCerts()) != null) {
         for(Enumeration var10 = var4.getObjects(); var10.hasMoreElements(); var11.reset()) {
            try {
               var11 = var2;
               var3.writeObject(var10.nextElement());
               var8.add(provider1.generateCertificate(new ByteArrayInputStream(var2.toByteArray())));
            } catch (IOException var5) {
               throw new OCSPException("can't re-encode certificate!", var5);
            } catch (CertificateException var6) {
               throw new OCSPException("can't re-encode certificate!", var6);
            }
         }
      }

      return var8;
   }

   private Set getExtensionOIDs(boolean critical) {
      OCSPReq var10000 = this;
      HashSet var5;
      var5 = new HashSet.<init>();
      X509Extensions var2;
      if ((var2 = var10000.getRequestExtensions()) != null) {
         Enumeration var3 = var2.oids();

         while(var3.hasMoreElements()) {
            DERObjectIdentifier var4;
            if (critical == var2.getExtension(var4 = (DERObjectIdentifier)var3.nextElement()).isCritical()) {
               var5.add(var4.getId());
            }
         }
      }

      return var5;
   }

   public byte[] getTBSRequest() {
      try {
         return this.req.getTbsRequest().getEncoded();
      } catch (IOException var1) {
         throw new OCSPException("problem encoding tbsRequest", var1);
      }
   }

   public int getVersion() {
      return this.req.getTbsRequest().getVersion().getValue().intValue() + 1;
   }

   public GeneralName getRequestorName() {
      return GeneralName.getInstance(this.req.getTbsRequest().getRequestorName());
   }

   public Req[] getRequestList() {
      int var1;
      ASN1Sequence var5;
      Req[] var2 = new Req[var1 = (var5 = this.req.getTbsRequest().getRequestList()).size()];

      for(int var3 = 0; var3 != var1; ++var3) {
         Req var4;
         var4 = new Req.<init>(Request.getInstance(var5.getObjectAt(var3)));
         var2[var3] = var4;
      }

      return var2;
   }

   public X509Extensions getRequestExtensions() {
      return X509Extensions.getInstance(this.req.getTbsRequest().getRequestExtensions());
   }

   public String getSignatureAlgOID() {
      return !this.isSigned() ? null : this.req.getOptionalSignature().getSignatureAlgorithm().getObjectId().getId();
   }

   public byte[] getSignature() {
      return !this.isSigned() ? null : this.req.getOptionalSignature().getSignature().getBytes();
   }

   public X509Certificate[] getCerts(String provider) {
      if (!this.isSigned()) {
         return null;
      } else {
         List var10000 = this.getCertList(provider);
         return (X509Certificate[])var10000.toArray(new X509Certificate[var10000.size()]);
      }
   }

   public CertStore getCertificates(String type, String provider) {
      if (!this.isSigned()) {
         return null;
      } else {
         InvalidAlgorithmParameterException var10000;
         label27: {
            boolean var10001;
            String var6;
            CollectionCertStoreParameters var7;
            try {
               var6 = type;
               var7 = new CollectionCertStoreParameters;
            } catch (InvalidAlgorithmParameterException var4) {
               var10000 = var4;
               var10001 = false;
               break label27;
            }

            CollectionCertStoreParameters var10002 = var7;

            try {
               var10002.<init>(this.getCertList(provider));
               return CertStore.getInstance(var6, var7, provider);
            } catch (InvalidAlgorithmParameterException var3) {
               var10000 = var3;
               var10001 = false;
            }
         }

         InvalidAlgorithmParameterException var5 = var10000;
         throw new OCSPException("can't setup the CertStore", var5);
      }
   }

   public boolean isSigned() {
      return this.req.getOptionalSignature() != null;
   }

   public boolean verify(PublicKey key, String sigProvider) {
      if (this.isSigned()) {
         Exception var10000;
         label53: {
            NoSuchProviderException var13;
            Signature var14;
            boolean var10001;
            try {
               var14 = Signature.getInstance(this.getSignatureAlgOID(), sigProvider);
            } catch (NoSuchProviderException var9) {
               var13 = var9;
               var10001 = false;
               throw var13;
            } catch (Exception var10) {
               var10000 = var10;
               var10001 = false;
               break label53;
            }

            Signature var15 = var14;

            OCSPReq var16;
            Signature var10002;
            ByteArrayOutputStream var10003;
            try {
               var10002 = var15;
               var16 = this;
               var10002.initVerify(key);
               var10003 = new ByteArrayOutputStream;
            } catch (NoSuchProviderException var7) {
               var13 = var7;
               var10001 = false;
               throw var13;
            } catch (Exception var8) {
               var10000 = var8;
               var10001 = false;
               break label53;
            }

            ByteArrayOutputStream key1;
            ByteArrayOutputStream var10004 = key1 = var10003;

            ASN1OutputStream var17;
            try {
               var10004.<init>();
               var17 = new ASN1OutputStream;
            } catch (NoSuchProviderException var5) {
               var13 = var5;
               var10001 = false;
               throw var13;
            } catch (Exception var6) {
               var10000 = var6;
               var10001 = false;
               break label53;
            }

            ASN1OutputStream var10005 = var17;

            try {
               var10005.<init>(key1);
               var17.writeObject(this.req.getTbsRequest());
               var10002.update(var10003.toByteArray());
               return var14.verify(var16.getSignature());
            } catch (NoSuchProviderException var3) {
               var13 = var3;
               var10001 = false;
               throw var13;
            } catch (Exception var4) {
               var10000 = var4;
               var10001 = false;
            }
         }

         Exception var11 = var10000;
         throw new OCSPException("exception processing sig: " + var11, var11);
      } else {
         throw new OCSPException("attempt to verify signature on unsigned object");
      }
   }

   public byte[] getEncoded() {
      ByteArrayOutputStream var1;
      ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
      var10000.<init>();
      (new ASN1OutputStream(var1)).writeObject(this.req);
      return var10000.toByteArray();
   }

   public boolean hasUnsupportedCriticalExtension() {
      Set var1;
      return (var1 = this.getCriticalExtensionOIDs()) != null && !var1.isEmpty();
   }

   public Set getCriticalExtensionOIDs() {
      return this.getExtensionOIDs(true);
   }

   public Set getNonCriticalExtensionOIDs() {
      return this.getExtensionOIDs(false);
   }

   public byte[] getExtensionValue(String oid) {
      X509Extensions var3;
      if ((var3 = this.getRequestExtensions()) != null) {
         X509Extensions var10000 = var3;
         DERObjectIdentifier var5;
         var5 = new DERObjectIdentifier.<init>(oid);
         cn.com.infosec.asn1.x509.X509Extension var6;
         if ((var6 = var10000.getExtension(var5)) != null) {
            ByteArrayOutputStream oid1;
            ByteArrayOutputStream var4 = oid1 = new ByteArrayOutputStream;
            var4.<init>();
            cn.com.infosec.asn1.x509.X509Extension var10002 = var6;
            DEROutputStream var10001 = new DEROutputStream(oid1);

            try {
               var10001.writeObject(var10002.getValue());
               return var4.toByteArray();
            } catch (Exception var2) {
               throw new RuntimeException("error encoding " + var2.toString());
            }
         }
      }

      return null;
   }
}
